# Generated by Django 4.1.8 on 2023-04-19 05:27

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("tags", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="WikiArticle",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("tag_detail_endpoint", models.CharField(blank=True, max_length=255, null=True)),
                ("tag_representation", models.CharField(blank=True, max_length=512, null=True)),
                ("title", models.CharField(max_length=1024)),
                ("content", models.TextField(default="")),
                ("summary", models.TextField(default="")),
                (
                    "tags",
                    models.ManyToManyField(blank=True, related_name="%(app_label)s_%(class)s_items", to="tags.tag"),
                ),
            ],
            options={
                "verbose_name": "Wiki Article",
                "verbose_name_plural": "Wiki Articles",
            },
        ),
    ]
